Python 3.15 speeds up Base32 135x but slows Base16 by 22%
pyperformance benchmarks on a Ryzen 9 7900 running Windows 11 show Python 3.15 encoding Base32 135x faster, Ascii85 69x faster, Base85 63x faster and Base64 3.6x faster thanks to C rewrites. Base16 regressed 22.3% versus Python 3.14 because it was not rewritten in C.
- Base32_large: 2.43 ms in 3.15 vs 327.6 ms in 3.14
- Ascii85_large: 11.62 ms vs 797.9 ms, a 69x speedup
- Base16_large slowed from 4.714 to 5.767 ms (+22.3%)
- Base64_large: 1.852 ms vs 6.746 ms in 3.14
Read next
Software